@@ -512,8 +512,12 @@ static int UnpackWPGRaster(Image *image,int bpp,ExceptionInfo *exception)
               return(-7);
             }
           RunCount=(unsigned char) c;
-          if(x) {    /* attempt to duplicate row from x position: */
-            /* I do not know what to do here */
+          if(x!=0) {    /* attempt to duplicate row from x position: */
+            if (InsertRow(image,BImgBuff,y,bpp,exception) == MagickFalse)
+              {
+                x=0;    
+                y++;
+              }
             BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
             return(-3);
           }
@@ -583,10 +587,10 @@ static int UnpackWPG2Raster(Image *image,int bpp,ExceptionInfo *exception)
   y=0;
   ldblk=(ssize_t) ((bpp*image->columns+7)/8);
   BImgBuff=(unsigned char *) AcquireQuantumMemory((size_t) ldblk,
-    sizeof(*BImgBuff));
+    8*sizeof(*BImgBuff));
   if(BImgBuff==NULL)
     return(-2);
-  (void) memset(BImgBuff,0,ldblk*sizeof(*BImgBuff));
+  (void) memset(BImgBuff,0,ldblk*8*sizeof(*BImgBuff));
 
   while( y< (ssize_t) image->rows)
   {
@@ -646,7 +650,7 @@ static int UnpackWPG2Raster(Image *image,int bpp,ExceptionInfo *exception)
             /* duplicate the previous row RunCount x */
             for(i=0;i<=RunCount;i++)
               {
-                if (InsertRow(image,BImgBuff,(ssize_t) ((ssize_t) image->rows > y ? y : image->rows-1),bpp,exception) == MagickFalse)
+                if (InsertRow(image,BImgBuff,((ssize_t) image->rows > y ? y : (ssize_t) image->rows-1),bpp,exception) == MagickFalse)
                   {
                     BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
                     return(-3);
@@ -1121,20 +1125,20 @@ static Image *ReadWPGImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           if (SeekBlob(image,Header.DataOffset,SEEK_SET) != Header.DataOffset)
             break;
-          if(EOFBlob(image))
+          if (EOFBlob(image))
             break;
-
           Rec.RecType=(i=ReadBlobByte(image));
-          if(i==EOF)
+          if (i==EOF)
             break;
           i=Rd_WP_DWORD(image,&Rec.RecordLength);
           if ((Rec.RecordLength+4) >= GetBlobSize(image))
             ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-          if(EOFBlob(image))
+          if (EOFBlob(image))
             break;
-
           Header.DataOffset=TellBlob(image)+Rec.RecordLength;
-
+          if (Header.DataOffset > (MagickOffsetType) GetBlobSize(image))
+            ThrowReaderException(CorruptImageError, 
+              "InsufficientImageDataInFile");
           switch(Rec.RecType)
             {
             case 0x0B: /* bitmap type 1 */
@@ -1756,7 +1760,7 @@ static void WPGAddRLEByte(WPGRLEInfo *rle_info,Image *image,
               rle_info->count++;
               WPGFlushRLE(rle_info,image,(unsigned char) (rle_info->offset-
                 rle_info->count-1));
-              (void) WriteBlobByte(image,(const unsigned char)
+              (void) WriteBlobByte(image,(unsigned char)
                 rle_info->count | 0x80);
               (void) WriteBlobByte(image,rle_info->pixels[0]);
               rle_info->offset=1;
@@ -1924,9 +1928,9 @@ static MagickBooleanType WriteWPGImage(const ImageInfo *image_info,Image *image,
   offset=TellBlob(image);
   (void) WriteBlobLSBShort(image,0x8000);
   (void) WriteBlobLSBShort(image,0);
-  (void) WriteBlobLSBShort(image,(const unsigned short) image->columns);
-  (void) WriteBlobLSBShort(image,(const unsigned short) image->rows);
-  (void) WriteBlobLSBShort(image,(const unsigned char) image->depth);
+  (void) WriteBlobLSBShort(image,(unsigned short) image->columns);
+  (void) WriteBlobLSBShort(image,(unsigned short) image->rows);
+  (void) WriteBlobLSBShort(image,(unsigned char) image->depth);
   (void) WriteBlobLSBShort(image,75);  /* resolution */
   (void) WriteBlobLSBShort(image,75);
   /*
